pub struct FeatureSet(pub BTreeSet<String>);Expand description
Sorted, deduplicated feature set.
BTreeSet ensures deterministic iteration order, which is critical for
producing identical hashes across platforms and invocations.
Tuple Fields
0: BTreeSet<String>Implementations
Sourceimpl FeatureSet
impl FeatureSet
Sourcepub fn short_hash(&self) -> String
pub fn short_hash(&self) -> String
Compute a short hash of the feature set for use in OCI tags. Returns first 8 hex chars of BLAKE3 hash over sorted features.