IdentityError

Enum IdentityError 

pub enum IdentityError {
    InvalidCrateName(String),
    InvalidCMetadata(String),
    InvalidTarget(String),
    InvalidCrateVersion(String),
    InvalidRustcVersion(String),
    InvalidFeatureName(String),
    UnsortedFeatures,
    InvalidEmitEntry(String),
    UnsortedEmit,
    InvalidJsonWrapper(String),
    UnsortedDependencyIdentities,
}
Errors produced while parsing wire identity values.

Variants



InvalidCrateName(String)

The crate name violates crates.io’s allowed character / length rules.



InvalidCMetadata(String)

The cargo -C metadata value is not a hex hash of length 1..=64.



InvalidTarget(String)

The target triple has unexpected characters or length.



InvalidCrateVersion(String)

The crate version is not semver.



InvalidRustcVersion(String)

The rustc version string failed shape validation.



InvalidFeatureName(String)

One feature name is empty, too long, or contains invalid characters.



UnsortedFeatures

A feature list was not strictly sorted and deduplicated.



InvalidEmitEntry(String)

An emit entry is empty, too long, or contains invalid characters.



UnsortedEmit

An emit list was not strictly sorted and deduplicated.



InvalidJsonWrapper(String)

Failed to parse a JSON wrapper string.



UnsortedDependencyIdentities

Dependency identities not sorted by (crate_name, c_metadata).